cumulusci.tasks.salesforce package
==================================

.. automodule:: cumulusci.tasks.salesforce
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

cumulusci.tasks.salesforce.BaseRetrieveMetadata module
------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.BaseRetrieveMetadata
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.BaseSalesforceApiTask module
-------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.BaseSalesforceApiTask
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.BaseSalesforceMetadataApiTask module
---------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.BaseSalesforceMetadataApiTask
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.BaseSalesforceTask module
----------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.BaseSalesforceTask
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.BaseUninstallMetadata module
-------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.BaseUninstallMetadata
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.CreateCommunity module
-------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.CreateCommunity
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.CreatePackage module
-----------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.CreatePackage
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.Deploy module
----------------------------------------

.. automodule:: cumulusci.tasks.salesforce.Deploy
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.DeployBundles module
-----------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.DeployBundles
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.EnsureRecordTypes module
---------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.EnsureRecordTypes
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.GetInstalledPackages module
------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.GetInstalledPackages
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.InstallPackageVersion module
-------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.InstallPackageVersion
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.ListCommunities module
-------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.ListCommunities
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.ListCommunityTemplates module
--------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.ListCommunityTemplates
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.PublishCommunity module
--------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.PublishCommunity
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.RetrievePackaged module
--------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.RetrievePackaged
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.RetrieveReportsAndDashboards module
--------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.RetrieveReportsAndDashboards
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.RetrieveUnpackaged module
----------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.RetrieveUnpackaged
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.SOQLQuery module
-------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.SOQLQuery
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.UninstallLocal module
------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.UninstallLocal
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.UninstallLocalBundles module
-------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.UninstallLocalBundles
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.UninstallLocalNamespacedBundles module
-----------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.UninstallLocalNamespacedBundles
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.UninstallPackage module
--------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.UninstallPackage
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.UninstallPackaged module
---------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.UninstallPackaged
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.UninstallPackagedIncremental module
--------------------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.UninstallPackagedIncremental
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.UpdateDependencies module
----------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.UpdateDependencies
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.activate\_flow module
------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.activate_flow
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.custom\_settings module
--------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.custom_settings
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.insert\_record module
------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.insert_record
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.org\_settings module
-----------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.org_settings
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.package\_upload module
-------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.package_upload
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.sourcetracking module
------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.sourcetracking
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.trigger\_handlers module
---------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.trigger_handlers
   :members:
   :undoc-members:
   :show-inheritance:

cumulusci.tasks.salesforce.update\_profile module
-------------------------------------------------

.. automodule:: cumulusci.tasks.salesforce.update_profile
   :members:
   :undoc-members:
   :show-inheritance:

